==> estateplat-common-1.2.3-20180122.055848-20-sources.jar: cn/gtmap/estateplat/model/commodityHouse/contract/FcjyXjspfMmhtQtsx.java <==
package cn.gtmap.estateplat.model.commodityHouse.contract;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/*
 * @author <a href="mailto:lizhi@gtmap.cn">lizhi</a>
 * @version 1.0, 2017/12/6
 * @description    其他事项表(第十章)
 */
@Table(name = "fcjy_xjspf_mmht_qtsx")
public class FcjyXjspfMmhtQtsx {
    @Id
    private String sxid;//主键
    private String htid;//合同ID
    private String yzgybw;//业主共有部位
    private String ckyd;//车库约定
    private String hsyd;//会所约定
    private String qtyd;//其他约定
    private String sycn6;//使用承诺6
    private String sycn7;//使用承诺7
    private String sdfs;//送达方式
    private Integer bgtzqx;//变更通知期限(天)
    private String zyjjfs;//争议解决方式
    private String zcwyhmc;//仲裁委员会名称
    private Integer fjys;//附件页数
    private Integer fjfs;//附件份数
    private Integer cmrfs;//出卖人份数
    private Integer msrfs;//买受人份数
    private String qtfmc;//其他方名称
    private Integer qtffs;//其他方份数
    private Date cmrqdsj;//出卖人签订时间
    private String cmrqddd;//出卖人签订地点
    private Date msrqdsj;//买受人签订时间
    private String msrqddd;//买受人签订地点
    private String wqcl;//外墙材料
    private String wqydnr;//外墙约定内容
    private String qjsnqcl;//起居室内墙材料
    private String qjsnqydnr;//起居室内墙约定内容
    private String qjsdpcl;//起居室顶棚材料
    private String qjsdpydnr;//起居室顶棚约定内容
    private String qjssndmcl;//起居室室内地面材料
    private String qjssndmydnr;//起居室室内地面约定内容
    private String cfdmcl;//厨房地面材料
    private String cfdmydnr;//厨房地面约定内容
    private String cfqmcl;//厨房墙面材料
    private String cfqmydnr;//厨房墙面约定内容
    private String cfdpcl;//厨房顶棚材料
    private String cfdpydnr;//厨房顶棚约定内容
    private String cfcjydnr;//厨房厨具约定内容
    private String wsjdmcl;//卫生间地面材料
    private String wsjdmydnr;//卫生间地面约定内容
    private String wsjqmcl;//卫生间墙面材料
    private String wsjqmydnr;//卫生间墙面约定内容
    private String wsjdpcl;//卫生间顶棚材料
    private String wsjdpydnr;//卫生间顶棚约定内容
    private String wsqjydnr;//卫生器具约定内容
    private String ytcl;//阳台材料
    private String ytydnr;//阳台约定内容
    private String dtpp;//电梯品牌
    private String dtxh;//电梯型号
    private String gdydnr;//管道约定内容
    private String chydnr;//窗户约定内容
    private String qtydnr1;//其他约定内容1
    private String qtydnr2;//其他约定内容2
    private Integer djztbxqx;//地基主体保修期限(年)
    private String djztyd;//地基主体约定
    private Integer fsbxqx;//防水保修期限(年)
    private String fsyd;//防水约定
    private Integer grglbxqx;//供热供冷保修期限(年)
    private String grglyd;//供热供冷约定
    private Integer gxgdbxqx;//管线管道保修期限(年)
    private String gxgdyd;//管线管道约定
    private Integer zxgcbxqx;//装修工程保修期限(年)
    private String zxgcyd;//装修工程约定
    private String bxxm1;//保修项目1
    private String bxxm2;//保修项目2
    private String bxxm3;//保修项目3
    private String bxqtyd;//保修其他约定
    private String qtfmc1;//其他方名称1
    private Integer qtffs1;//其他方份数1

    public String getSxid() {
        return sxid;
    }

    public void setSxid(String sxid) {
        this.sxid = sxid;
    }

    public String getHtid() {
        return htid;
    }

    public void setHtid(String htid) {
        this.htid = htid;
    }

    public String getYzgybw() {
        return yzgybw;
    }

    public void setYzgybw(String yzgybw) {
        this.yzgybw = yzgybw;
    }

    public String getCkyd() {
        return ckyd;
    }

    public void setCkyd(String ckyd) {
        this.ckyd = ckyd;
    }

    public String getHsyd() {
        return hsyd;
    }

    public void setHsyd(String hsyd) {
        this.hsyd = hsyd;
    }

    public String getQtyd() {
        return qtyd;
    }

    public void setQtyd(String qtyd) {
        this.qtyd = qtyd;
    }

    public String getSycn6() {
        return sycn6;
    }

    public void setSycn6(String sycn6) {
        this.sycn6 = sycn6;
    }

    public String getSycn7() {
        return sycn7;
    }

    public void setSycn7(String sycn7) {
        this.sycn7 = sycn7;
    }

    public String getSdfs() {
        return sdfs;
    }

    public void setSdfs(String sdfs) {
        this.sdfs = sdfs;
    }

    public Integer getBgtzqx() {
        return bgtzqx;
    }

    public void setBgtzqx(Integer bgtzqx) {
        this.bgtzqx = bgtzqx;
    }

    public String getZyjjfs() {
        return zyjjfs;
    }

    public void setZyjjfs(String zyjjfs) {
        this.zyjjfs = zyjjfs;
    }

    public String getZcwyhmc() {
        return zcwyhmc;
    }

    public void setZcwyhmc(String zcwyhmc) {
        this.zcwyhmc = zcwyhmc;
    }

    public Integer getFjys() {
        return fjys;
    }

    public void setFjys(Integer fjys) {
        this.fjys = fjys;
    }

    public Integer getFjfs() {
        return fjfs;
    }

    public void setFjfs(Integer fjfs) {
        this.fjfs = fjfs;
    }

    public Integer getCmrfs() {
        return cmrfs;
    }

    public void setCmrfs(Integer cmrfs) {
        this.cmrfs = cmrfs;
    }

    public Integer getMsrfs() {
        return msrfs;
    }

    public void setMsrfs(Integer msrfs) {
        this.msrfs = msrfs;
    }

    public String getQtfmc() {
        return qtfmc;
    }

    public void setQtfmc(String qtfmc) {
        this.qtfmc = qtfmc;
    }

    public Integer getQtffs() {
        return qtffs;
    }

    public void setQtffs(Integer qtffs) {
        this.qtffs = qtffs;
    }

    public Date getCmrqdsj() {
        return cmrqdsj;
    }

    public void setCmrqdsj(Date cmrqdsj) {
        this.cmrqdsj = cmrqdsj;
    }

    public String getCmrqddd() {
        return cmrqddd;
    }

    public void setCmrqddd(String cmrqddd) {
        this.cmrqddd = cmrqddd;
    }

    public Date getMsrqdsj() {
        return msrqdsj;
    }

    public void setMsrqdsj(Date msrqdsj) {
        this.msrqdsj = msrqdsj;
    }

    public String getMsrqddd() {
        return msrqddd;
    }

    public void setMsrqddd(String msrqddd) {
        this.msrqddd = msrqddd;
    }

    public String getWqcl() {
        return wqcl;
    }

    public void setWqcl(String wqcl) {
        this.wqcl = wqcl;
    }

    public String getWqydnr() {
        return wqydnr;
    }

    public void setWqydnr(String wqydnr) {
        this.wqydnr = wqydnr;
    }

    public String getQjsnqcl() {
        return qjsnqcl;
    }

    public void setQjsnqcl(String qjsnqcl) {
        this.qjsnqcl = qjsnqcl;
    }

    public String getQjsnqydnr() {
        return qjsnqydnr;
    }

    public void setQjsnqydnr(String qjsnqydnr) {
        this.qjsnqydnr = qjsnqydnr;
    }

    public String getQjsdpcl() {
        return qjsdpcl;
    }

    public void setQjsdpcl(String qjsdpcl) {
        this.qjsdpcl = qjsdpcl;
    }

    public String getQjsdpydnr() {
        return qjsdpydnr;
    }

    public void setQjsdpydnr(String qjsdpydnr) {
        this.qjsdpydnr = qjsdpydnr;
    }

    public String getQjssndmcl() {
        return qjssndmcl;
    }

    public void setQjssndmcl(String qjssndmcl) {
        this.qjssndmcl = qjssndmcl;
    }

    public String getQjssndmydnr() {
        return qjssndmydnr;
    }

    public void setQjssndmydnr(String qjssndmydnr) {
        this.qjssndmydnr = qjssndmydnr;
    }

    public String getCfdmcl() {
        return cfdmcl;
    }

    public void setCfdmcl(String cfdmcl) {
        this.cfdmcl = cfdmcl;
    }

    public String getCfdmydnr() {
        return cfdmydnr;
    }

    public void setCfdmydnr(String cfdmydnr) {
        this.cfdmydnr = cfdmydnr;
    }

    public String getCfqmcl() {
        return cfqmcl;
    }

    public void setCfqmcl(String cfqmcl) {
        this.cfqmcl = cfqmcl;
    }

    public String getCfqmydnr() {
        return cfqmydnr;
    }

    public void setCfqmydnr(String cfqmydnr) {
        this.cfqmydnr = cfqmydnr;
    }

    public String getCfdpcl() {
        return cfdpcl;
    }

    public void setCfdpcl(String cfdpcl) {
        this.cfdpcl = cfdpcl;
    }

    public String getCfdpydnr() {
        return cfdpydnr;
    }

    public void setCfdpydnr(String cfdpydnr) {
        this.cfdpydnr = cfdpydnr;
    }

    public String getCfcjydnr() {
        return cfcjydnr;
    }

    public void setCfcjydnr(String cfcjydnr) {
        this.cfcjydnr = cfcjydnr;
    }

    public String getWsjdmcl() {
        return wsjdmcl;
    }

    public void setWsjdmcl(String wsjdmcl) {
        this.wsjdmcl = wsjdmcl;
    }

    public String getWsjdmydnr() {
        return wsjdmydnr;
    }

    public void setWsjdmydnr(String wsjdmydnr) {
        this.wsjdmydnr = wsjdmydnr;
    }

    public String getWsjqmcl() {
        return wsjqmcl;
    }

    public void setWsjqmcl(String wsjqmcl) {
        this.wsjqmcl = wsjqmcl;
    }

    public String getWsjqmydnr() {
        return wsjqmydnr;
    }

    public void setWsjqmydnr(String wsjqmydnr) {
        this.wsjqmydnr = wsjqmydnr;
    }

    public String getWsjdpcl() {
        return wsjdpcl;
    }

    public void setWsjdpcl(String wsjdpcl) {
        this.wsjdpcl = wsjdpcl;
    }

    public String getWsjdpydnr() {
        return wsjdpydnr;
    }

    public void setWsjdpydnr(String wsjdpydnr) {
        this.wsjdpydnr = wsjdpydnr;
    }

    public String getWsqjydnr() {
        return wsqjydnr;
    }

    public void setWsqjydnr(String wsqjydnr) {
        this.wsqjydnr = wsqjydnr;
    }

    public String getYtcl() {
        return ytcl;
    }

    public void setYtcl(String ytcl) {
        this.ytcl = ytcl;
    }

    public String getYtydnr() {
        return ytydnr;
    }

    public void setYtydnr(String ytydnr) {
        this.ytydnr = ytydnr;
    }

    public String getDtpp() {
        return dtpp;
    }

    public void setDtpp(String dtpp) {
        this.dtpp = dtpp;
    }

    public String getDtxh() {
        return dtxh;
    }

    public void setDtxh(String dtxh) {
        this.dtxh = dtxh;
    }

    public String getGdydnr() {
        return gdydnr;
    }

    public void setGdydnr(String gdydnr) {
        this.gdydnr = gdydnr;
    }

    public String getChydnr() {
        return chydnr;
    }

    public void setChydnr(String chydnr) {
        this.chydnr = chydnr;
    }

    public String getQtydnr1() {
        return qtydnr1;
    }

    public void setQtydnr1(String qtydnr1) {
        this.qtydnr1 = qtydnr1;
    }

    public String getQtydnr2() {
        return qtydnr2;
    }

    public void setQtydnr2(String qtydnr2) {
        this.qtydnr2 = qtydnr2;
    }

    public Integer getDjztbxqx() {
        return djztbxqx;
    }

    public void setDjztbxqx(Integer djztbxqx) {
        this.djztbxqx = djztbxqx;
    }

    public String getDjztyd() {
        return djztyd;
    }

    public void setDjztyd(String djztyd) {
        this.djztyd = djztyd;
    }

    public Integer getFsbxqx() {
        return fsbxqx;
    }

    public void setFsbxqx(Integer fsbxqx) {
        this.fsbxqx = fsbxqx;
    }

    public String getFsyd() {
        return fsyd;
    }

    public void setFsyd(String fsyd) {
        this.fsyd = fsyd;
    }

    public Integer getGrglbxqx() {
        return grglbxqx;
    }

    public void setGrglbxqx(Integer grglbxqx) {
        this.grglbxqx = grglbxqx;
    }

    public String getGrglyd() {
        return grglyd;
    }

    public void setGrglyd(String grglyd) {
        this.grglyd = grglyd;
    }

    public Integer getGxgdbxqx() {
        return gxgdbxqx;
    }

    public void setGxgdbxqx(Integer gxgdbxqx) {
        this.gxgdbxqx = gxgdbxqx;
    }

    public String getGxgdyd() {
        return gxgdyd;
    }

    public void setGxgdyd(String gxgdyd) {
        this.gxgdyd = gxgdyd;
    }

    public Integer getZxgcbxqx() {
        return zxgcbxqx;
    }

    public void setZxgcbxqx(Integer zxgcbxqx) {
        this.zxgcbxqx = zxgcbxqx;
    }

    public String getZxgcyd() {
        return zxgcyd;
    }

    public void setZxgcyd(String zxgcyd) {
        this.zxgcyd = zxgcyd;
    }

    public String getBxxm1() {
        return bxxm1;
    }

    public void setBxxm1(String bxxm1) {
        this.bxxm1 = bxxm1;
    }

    public String getBxxm2() {
        return bxxm2;
    }

    public void setBxxm2(String bxxm2) {
        this.bxxm2 = bxxm2;
    }

    public String getBxxm3() {
        return bxxm3;
    }

    public void setBxxm3(String bxxm3) {
        this.bxxm3 = bxxm3;
    }

    public String getBxqtyd() {
        return bxqtyd;
    }

    public void setBxqtyd(String bxqtyd) {
        this.bxqtyd = bxqtyd;
    }

    public String getQtfmc1() {
        return qtfmc1;
    }

    public void setQtfmc1(String qtfmc1) {
        this.qtfmc1 = qtfmc1;
    }

    public Integer getQtffs1() {
        return qtffs1;
    }

    public void setQtffs1(Integer qtffs1) {
        this.qtffs1 = qtffs1;
    }
}

==> estateplat-common-1.2.3-20180419.082059-65-sources.jar: cn/gtmap/estateplat/model/commodityHouse/contract/FcjyXjspfMmhtQtsx.java <==
package cn.gtmap.estateplat.model.commodityHouse.contract;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/*
 * @author <a href="mailto:lizhi@gtmap.cn">lizhi</a>
 * @version 1.0, 2017/12/6
 * @description    其他事项表(第十章)
 */
@Table(name = "fcjy_xjspf_mmht_qtsx")
public class FcjyXjspfMmhtQtsx {
    @Id
    private String sxid;//主键
    private String htid;//合同ID
    private String yzgybw;//业主共有部位
    private String ckyd;//车库约定
    private String hsyd;//会所约定
    private String qtyd;//其他约定
    private String sycn6;//使用承诺6
    private String sycn7;//使用承诺7
    private String sdfs;//送达方式
    private Integer bgtzqx;//变更通知期限(天)
    private String zyjjfs;//争议解决方式
    private String zcwyhmc;//仲裁委员会名称
    private Integer fjys;//附件页数
    private Integer fjfs;//附件份数
    private Integer cmrfs;//出卖人份数
    private Integer msrfs;//买受人份数
    private String qtfmc;//其他方名称
    private Integer qtffs;//其他方份数
    private Date cmrqdsj;//出卖人签订时间
    private String cmrqddd;//出卖人签订地点
    private Date msrqdsj;//买受人签订时间
    private String msrqddd;//买受人签订地点
    private String wqcl;//外墙材料
    private String wqydnr;//外墙约定内容
    private String qjsnqcl;//起居室内墙材料
    private String qjsnqydnr;//起居室内墙约定内容
    private String qjsdpcl;//起居室顶棚材料
    private String qjsdpydnr;//起居室顶棚约定内容
    private String qjssndmcl;//起居室室内地面材料
    private String qjssndmydnr;//起居室室内地面约定内容
    private String cfdmcl;//厨房地面材料
    private String cfdmydnr;//厨房地面约定内容
    private String cfqmcl;//厨房墙面材料
    private String cfqmydnr;//厨房墙面约定内容
    private String cfdpcl;//厨房顶棚材料
    private String cfdpydnr;//厨房顶棚约定内容
    private String cfcjydnr;//厨房厨具约定内容
    private String wsjdmcl;//卫生间地面材料
    private String wsjdmydnr;//卫生间地面约定内容
    private String wsjqmcl;//卫生间墙面材料
    private String wsjqmydnr;//卫生间墙面约定内容
    private String wsjdpcl;//卫生间顶棚材料
    private String wsjdpydnr;//卫生间顶棚约定内容
    private String wsqjydnr;//卫生器具约定内容
    private String ytcl;//阳台材料
    private String ytydnr;//阳台约定内容
    private String dtpp;//电梯品牌
    private String dtxh;//电梯型号
    private String gdydnr;//管道约定内容
    private String chydnr;//窗户约定内容
    private String qtydnr1;//其他约定内容1
    private String qtydnr2;//其他约定内容2
    private String djztbxqx;//地基主体保修期限(年)
    private String djztyd;//地基主体约定
    private String fsbxqx;//防水保修期限(年)
    private String fsyd;//防水约定
    private String grglbxqx;//供热供冷保修期限(年)
    private String grglyd;//供热供冷约定
    private String gxgdbxqx;//管线管道保修期限(年)
    private String gxgdyd;//管线管道约定
    private String zxgcbxqx;//装修工程保修期限(年)
    private String zxgcyd;//装修工程约定
    private String bxxm1;//保修项目1
    private String bxxm2;//保修项目2
    private String bxxm3;//保修项目3
    private String bxqtyd;//保修其他约定
    private String qtfmc1;//其他方名称1
    private Integer qtffs1;//其他方份数1

    public String getSxid() {
        return sxid;
    }

    public void setSxid(String sxid) {
        this.sxid = sxid;
    }

    public String getHtid() {
        return htid;
    }

    public void setHtid(String htid) {
        this.htid = htid;
    }

    public String getYzgybw() {
        return yzgybw;
    }

    public void setYzgybw(String yzgybw) {
        this.yzgybw = yzgybw;
    }

    public String getCkyd() {
        return ckyd;
    }

    public void setCkyd(String ckyd) {
        this.ckyd = ckyd;
    }

    public String getHsyd() {
        return hsyd;
    }

    public void setHsyd(String hsyd) {
        this.hsyd = hsyd;
    }

    public String getQtyd() {
        return qtyd;
    }

    public void setQtyd(String qtyd) {
        this.qtyd = qtyd;
    }

    public String getSycn6() {
        return sycn6;
    }

    public void setSycn6(String sycn6) {
        this.sycn6 = sycn6;
    }

    public String getSycn7() {
        return sycn7;
    }

    public void setSycn7(String sycn7) {
        this.sycn7 = sycn7;
    }

    public String getSdfs() {
        return sdfs;
    }

    public void setSdfs(String sdfs) {
        this.sdfs = sdfs;
    }

    public Integer getBgtzqx() {
        return bgtzqx;
    }

    public void setBgtzqx(Integer bgtzqx) {
        this.bgtzqx = bgtzqx;
    }

    public String getZyjjfs() {
        return zyjjfs;
    }

    public void setZyjjfs(String zyjjfs) {
        this.zyjjfs = zyjjfs;
    }

    public String getZcwyhmc() {
        return zcwyhmc;
    }

    public void setZcwyhmc(String zcwyhmc) {
        this.zcwyhmc = zcwyhmc;
    }

    public Integer getFjys() {
        return fjys;
    }

    public void setFjys(Integer fjys) {
        this.fjys = fjys;
    }

    public Integer getFjfs() {
        return fjfs;
    }

    public void setFjfs(Integer fjfs) {
        this.fjfs = fjfs;
    }

    public Integer getCmrfs() {
        return cmrfs;
    }

    public void setCmrfs(Integer cmrfs) {
        this.cmrfs = cmrfs;
    }

    public Integer getMsrfs() {
        return msrfs;
    }

    public void setMsrfs(Integer msrfs) {
        this.msrfs = msrfs;
    }

    public String getQtfmc() {
        return qtfmc;
    }

    public void setQtfmc(String qtfmc) {
        this.qtfmc = qtfmc;
    }

    public Integer getQtffs() {
        return qtffs;
    }

    public void setQtffs(Integer qtffs) {
        this.qtffs = qtffs;
    }

    public Date getCmrqdsj() {
        return cmrqdsj;
    }

    public void setCmrqdsj(Date cmrqdsj) {
        this.cmrqdsj = cmrqdsj;
    }

    public String getCmrqddd() {
        return cmrqddd;
    }

    public void setCmrqddd(String cmrqddd) {
        this.cmrqddd = cmrqddd;
    }

    public Date getMsrqdsj() {
        return msrqdsj;
    }

    public void setMsrqdsj(Date msrqdsj) {
        this.msrqdsj = msrqdsj;
    }

    public String getMsrqddd() {
        return msrqddd;
    }

    public void setMsrqddd(String msrqddd) {
        this.msrqddd = msrqddd;
    }

    public String getWqcl() {
        return wqcl;
    }

    public void setWqcl(String wqcl) {
        this.wqcl = wqcl;
    }

    public String getWqydnr() {
        return wqydnr;
    }

    public void setWqydnr(String wqydnr) {
        this.wqydnr = wqydnr;
    }

    public String getQjsnqcl() {
        return qjsnqcl;
    }

    public void setQjsnqcl(String qjsnqcl) {
        this.qjsnqcl = qjsnqcl;
    }

    public String getQjsnqydnr() {
        return qjsnqydnr;
    }

    public void setQjsnqydnr(String qjsnqydnr) {
        this.qjsnqydnr = qjsnqydnr;
    }

    public String getQjsdpcl() {
        return qjsdpcl;
    }

    public void setQjsdpcl(String qjsdpcl) {
        this.qjsdpcl = qjsdpcl;
    }

    public String getQjsdpydnr() {
        return qjsdpydnr;
    }

    public void setQjsdpydnr(String qjsdpydnr) {
        this.qjsdpydnr = qjsdpydnr;
    }

    public String getQjssndmcl() {
        return qjssndmcl;
    }

    public void setQjssndmcl(String qjssndmcl) {
        this.qjssndmcl = qjssndmcl;
    }

    public String getQjssndmydnr() {
        return qjssndmydnr;
    }

    public void setQjssndmydnr(String qjssndmydnr) {
        this.qjssndmydnr = qjssndmydnr;
    }

    public String getCfdmcl() {
        return cfdmcl;
    }

    public void setCfdmcl(String cfdmcl) {
        this.cfdmcl = cfdmcl;
    }

    public String getCfdmydnr() {
        return cfdmydnr;
    }

    public void setCfdmydnr(String cfdmydnr) {
        this.cfdmydnr = cfdmydnr;
    }

    public String getCfqmcl() {
        return cfqmcl;
    }

    public void setCfqmcl(String cfqmcl) {
        this.cfqmcl = cfqmcl;
    }

    public String getCfqmydnr() {
        return cfqmydnr;
    }

    public void setCfqmydnr(String cfqmydnr) {
        this.cfqmydnr = cfqmydnr;
    }

    public String getCfdpcl() {
        return cfdpcl;
    }

    public void setCfdpcl(String cfdpcl) {
        this.cfdpcl = cfdpcl;
    }

    public String getCfdpydnr() {
        return cfdpydnr;
    }

    public void setCfdpydnr(String cfdpydnr) {
        this.cfdpydnr = cfdpydnr;
    }

    public String getCfcjydnr() {
        return cfcjydnr;
    }

    public void setCfcjydnr(String cfcjydnr) {
        this.cfcjydnr = cfcjydnr;
    }

    public String getWsjdmcl() {
        return wsjdmcl;
    }

    public void setWsjdmcl(String wsjdmcl) {
        this.wsjdmcl = wsjdmcl;
    }

    public String getWsjdmydnr() {
        return wsjdmydnr;
    }

    public void setWsjdmydnr(String wsjdmydnr) {
        this.wsjdmydnr = wsjdmydnr;
    }

    public String getWsjqmcl() {
        return wsjqmcl;
    }

    public void setWsjqmcl(String wsjqmcl) {
        this.wsjqmcl = wsjqmcl;
    }

    public String getWsjqmydnr() {
        return wsjqmydnr;
    }

    public void setWsjqmydnr(String wsjqmydnr) {
        this.wsjqmydnr = wsjqmydnr;
    }

    public String getWsjdpcl() {
        return wsjdpcl;
    }

    public void setWsjdpcl(String wsjdpcl) {
        this.wsjdpcl = wsjdpcl;
    }

    public String getWsjdpydnr() {
        return wsjdpydnr;
    }

    public void setWsjdpydnr(String wsjdpydnr) {
        this.wsjdpydnr = wsjdpydnr;
    }

    public String getWsqjydnr() {
        return wsqjydnr;
    }

    public void setWsqjydnr(String wsqjydnr) {
        this.wsqjydnr = wsqjydnr;
    }

    public String getYtcl() {
        return ytcl;
    }

    public void setYtcl(String ytcl) {
        this.ytcl = ytcl;
    }

    public String getYtydnr() {
        return ytydnr;
    }

    public void setYtydnr(String ytydnr) {
        this.ytydnr = ytydnr;
    }

    public String getDtpp() {
        return dtpp;
    }

    public void setDtpp(String dtpp) {
        this.dtpp = dtpp;
    }

    public String getDtxh() {
        return dtxh;
    }

    public void setDtxh(String dtxh) {
        this.dtxh = dtxh;
    }

    public String getGdydnr() {
        return gdydnr;
    }

    public void setGdydnr(String gdydnr) {
        this.gdydnr = gdydnr;
    }

    public String getChydnr() {
        return chydnr;
    }

    public void setChydnr(String chydnr) {
        this.chydnr = chydnr;
    }

    public String getQtydnr1() {
        return qtydnr1;
    }

    public void setQtydnr1(String qtydnr1) {
        this.qtydnr1 = qtydnr1;
    }

    public String getQtydnr2() {
        return qtydnr2;
    }

    public void setQtydnr2(String qtydnr2) {
        this.qtydnr2 = qtydnr2;
    }

    public String getDjztyd() {
        return djztyd;
    }

    public void setDjztyd(String djztyd) {
        this.djztyd = djztyd;
    }

    public String getFsyd() {
        return fsyd;
    }

    public void setFsyd(String fsyd) {
        this.fsyd = fsyd;
    }

    public String getGrglyd() {
        return grglyd;
    }

    public void setGrglyd(String grglyd) {
        this.grglyd = grglyd;
    }

    public String getGxgdyd() {
        return gxgdyd;
    }

    public void setGxgdyd(String gxgdyd) {
        this.gxgdyd = gxgdyd;
    }

    public String getZxgcyd() {
        return zxgcyd;
    }

    public void setZxgcyd(String zxgcyd) {
        this.zxgcyd = zxgcyd;
    }

    public String getBxxm1() {
        return bxxm1;
    }

    public void setBxxm1(String bxxm1) {
        this.bxxm1 = bxxm1;
    }

    public String getBxxm2() {
        return bxxm2;
    }

    public void setBxxm2(String bxxm2) {
        this.bxxm2 = bxxm2;
    }

    public String getBxxm3() {
        return bxxm3;
    }

    public void setBxxm3(String bxxm3) {
        this.bxxm3 = bxxm3;
    }

    public String getBxqtyd() {
        return bxqtyd;
    }

    public void setBxqtyd(String bxqtyd) {
        this.bxqtyd = bxqtyd;
    }

    public String getQtfmc1() {
        return qtfmc1;
    }

    public void setQtfmc1(String qtfmc1) {
        this.qtfmc1 = qtfmc1;
    }

    public Integer getQtffs1() {
        return qtffs1;
    }

    public void setQtffs1(Integer qtffs1) {
        this.qtffs1 = qtffs1;
    }

    public String getDjztbxqx() {
        return djztbxqx;
    }

    public void setDjztbxqx(String djztbxqx) {
        this.djztbxqx = djztbxqx;
    }

    public String getFsbxqx() {
        return fsbxqx;
    }

    public void setFsbxqx(String fsbxqx) {
        this.fsbxqx = fsbxqx;
    }

    public String getGrglbxqx() {
        return grglbxqx;
    }

    public void setGrglbxqx(String grglbxqx) {
        this.grglbxqx = grglbxqx;
    }

    public String getGxgdbxqx() {
        return gxgdbxqx;
    }

    public void setGxgdbxqx(String gxgdbxqx) {
        this.gxgdbxqx = gxgdbxqx;
    }

    public String getZxgcbxqx() {
        return zxgcbxqx;
    }

    public void setZxgcbxqx(String zxgcbxqx) {
        this.zxgcbxqx = zxgcbxqx;
    }
}
